__author__ = """Luigi Petrucco @brainglobe"""
__version__ = "0.6.0"

from brainglobe_space.core import AnatomicalSpace, SpaceConvention
from brainglobe_space.functions import (
    map_to,
    map_stack_to,
    transformation_matrix_to,
    transform_points_to,
)
